==> local-booter-3.8.3-sources.jar: com/xebialabs/deployit/booter/local/VerificationConverter.java <==
package com.xebialabs.deployit.booter.local;

import java.lang.annotation.Annotation;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Map;
import java.util.Set;
import org.w3c.dom.Attr;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import com.google.common.collect.Maps;

import com.xebialabs.deployit.plugin.api.reflect.Type;
import com.xebialabs.deployit.plugin.api.reflect.TypeVerification;
import com.xebialabs.deployit.plugin.api.reflect.Verify;
import com.xebialabs.deployit.plugin.api.validation.Rule;
import com.xebialabs.deployit.plugin.api.validation.Validator;

import nl.javadude.scannit.Scannit;

import static com.xebialabs.deployit.booter.local.utils.ReflectionUtils.handleInvocationTargetException;
import static com.xebialabs.deployit.booter.local.utils.ReflectionUtils.setField;

class VerificationConverter {

    public static final String VERIFICATION_ELEMENT_NAME = "verification";

    private static final Map<String, Class<? extends TypeVerification>> verificationTypeMap = Maps.newHashMap();

    static {
        Set<Class<?>> rules = Scannit.getInstance().getTypesAnnotatedWith(Verify.class);
        for (Class<?> validationRuleAnnotation : rules) {
            Verify verify = validationRuleAnnotation.getAnnotation(Verify.class);
            verificationTypeMap.put(verify.type(), verify.clazz());
        }
    }

    static boolean isVerification(Annotation annotation) {
        return annotation.annotationType().isAnnotationPresent(Verify.class);
    }

    static TypeVerification makeVerification(Annotation verificationAnnotation) {
        Class<? extends Annotation> verificationClazz = verificationAnnotation.annotationType();
        Verify verify = verificationClazz.getAnnotation(Verify.class);
        return instantiate(verify.clazz());
    }

    static TypeVerification makeVerification(Element element, Type ciType) {
        String type = element.getAttribute("type");
        TypeVerification rule = createRule(type);
        if (rule != null) {
            return rule;
        }
        throw new IllegalArgumentException(String.format("Could not find verification type %s defined on type %s", type, ciType));
    }

    private static TypeVerification createRule(String type) {
        if (verificationTypeMap.containsKey(type)) {
            return instantiate(verificationTypeMap.get(type));
        }
        return null;
    }

    private static TypeVerification instantiate(Class<? extends TypeVerification> rule) {
        try {
            return rule.newInstance();
        } catch (InstantiationException e) {
            throw new IllegalStateException("Cannot instantiate validation rule " + rule, e);
        } catch (IllegalAccessException e) {
            throw new IllegalStateException("Cannot instantiate validation rule " + rule, e);
        }
    }
}

==> local-booter-10.0.0-1102.113-sources.jar: com/xebialabs/deployit/booter/local/VerificationConverter.java <==
package com.xebialabs.deployit.booter.local;

import com.xebialabs.deployit.plugin.api.reflect.Type;
import com.xebialabs.deployit.plugin.api.reflect.Verification;
import com.xebialabs.deployit.plugin.api.reflect.Verify;
import nl.javadude.scannit.Scannit;
import org.w3c.dom.Element;

import java.lang.annotation.Annotation;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

class VerificationConverter {

    public static final String VERIFICATION_ELEMENT_NAME = "verification";

    private static final Map<String, Class<? extends Verification>> verificationTypeMap = new HashMap<>();

    static {
        Set<Class<?>> rules = Scannit.getInstance().getTypesAnnotatedWith(Verify.class);
        for (Class<?> validationRuleAnnotation : rules) {
            Verify verify = validationRuleAnnotation.getAnnotation(Verify.class);
            verificationTypeMap.put(verify.type(), verify.clazz());
        }
    }

    static boolean isVerification(Annotation annotation) {
        return annotation.annotationType().isAnnotationPresent(Verify.class);
    }

    @SuppressWarnings("unchecked")
    static <T extends Verification> T makeVerification(Annotation verificationAnnotation) {
        Class<? extends Annotation> verificationClazz = verificationAnnotation.annotationType();
        Verify verify = verificationClazz.getAnnotation(Verify.class);
        return (T) instantiate(verify.clazz());
    }

    @SuppressWarnings("unchecked")
    static <T extends Verification> T makeVerification(Element element, Type ciType) {
        String type = element.getAttribute("type");
        T rule = (T) createRule(type);
        if (rule != null) {
            return rule;
        }
        throw new IllegalArgumentException(String.format("Could not find verification type %s defined on type %s", type, ciType));
    }

    private static Verification createRule(String type) {
        if (verificationTypeMap.containsKey(type)) {
            return instantiate(verificationTypeMap.get(type));
        }
        return null;
    }

    private static Verification instantiate(Class<? extends Verification> rule) {
        try {
            return rule.newInstance();
        } catch (InstantiationException e) {
            throw new IllegalStateException("Cannot instantiate validation rule " + rule, e);
        } catch (IllegalAccessException e) {
            throw new IllegalStateException("Cannot instantiate validation rule " + rule, e);
        }
    }
}
